@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: downloader-view.c,v 1.92 2006/02/02 17:27:40 chpe Exp $
+ *  $Id: downloader-view.c,v 1.97 2006/06/18 18:19:02 chpe Exp $
  */
 
 #include "config.h" 
@@ -29,9 +29,8 @@
 #include "ephy-gui.h"
 #include "ephy-debug.h"
 
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <eggstatusicon.h>
-#include <eggtraymanager.h>
+#include <glib/gi18n.h>
+#include <gtk/gtkversion.h>
 #include <gtk/gtktreeview.h>
 #include <gtk/gtkliststore.h>
 #include <gtk/gtkbutton.h>
@@ -46,8 +45,9 @@
 #include <gtk/gtkmenushell.h>
 #include <gtk/gtkmenu.h>
 #include <gtk/gtkmain.h>
+#include <gtk/gtkstatusicon.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomeui/gnome-icon-lookup.h>
-#include <glib/gi18n.h>
 
 #define CONF_DOWNLOADING_SHOW_DETAILS "/apps/epiphany/dialogs/downloader_show_details"
 
@@ -81,7 +81,7 @@ struct _DownloaderViewPrivate
 	GtkWidget *pause_button;
 	GtkWidget *abort_button;
 
-	EggStatusIcon *status_icon;
+	GtkStatusIcon *status_icon;
 
 	guint idle_unref : 1;
 };
@@ -177,11 +177,12 @@ show_downloader_cb (DownloaderView *dv)
 }
 
 static gboolean
-status_icon_popup_menu_cb (EggStatusIcon *icon,
+status_icon_popup_menu_cb (GtkStatusIcon *icon,
+			   guint button,
+			   guint time,
                            DownloaderView *dv)
 {
         GtkWidget *menu, *item;
-	guint button = 0;
 
 	menu = gtk_menu_new ();
 
@@ -193,8 +194,8 @@ status_icon_popup_menu_cb (EggStatusIcon *icon,
 	gtk_widget_show_all (menu);
 
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
-			ephy_gui_menu_position_on_panel, icon->tray_icon,
-			button, gtk_get_current_event_time ());
+			gtk_status_icon_position_menu, icon,
+			button, time);
 
 	return TRUE;
 }
@@ -202,16 +203,14 @@ status_icon_popup_menu_cb (EggStatusIcon *icon,
 static void
 show_status_icon (DownloaderView *dv)
 {
-	GdkPixbuf *pixbuf;
+	DownloaderViewPrivate *priv = dv->priv;
 
-	pixbuf = gdk_pixbuf_new_from_file (ephy_file ("epiphany-download.png"), NULL);
-	dv->priv->status_icon = egg_status_icon_new_from_pixbuf (pixbuf);
-	g_object_unref (pixbuf);
+	priv->status_icon = gtk_status_icon_new_from_stock (EPHY_STOCK_DOWNLOAD);
 
-	g_signal_connect_swapped (dv->priv->status_icon, "activate",
+	g_signal_connect_swapped (priv->status_icon, "activate",
 				  G_CALLBACK (show_downloader_cb), dv);
 	g_signal_connect (dv->priv->status_icon, "popup-menu",
-			  G_CALLBACK(status_icon_popup_menu_cb), dv);
+			  G_CALLBACK (status_icon_popup_menu_cb), dv);
 }
 
 static gboolean
@@ -275,9 +274,15 @@ static void
 downloader_view_finalize (GObject *object)
 {
 	DownloaderView *dv = EPHY_DOWNLOADER_VIEW (object);
+	DownloaderViewPrivate *priv = dv->priv;
 	gboolean idle_unref = dv->priv->idle_unref;
 
-	g_object_unref (dv->priv->status_icon);
+	if (priv->status_icon != NULL)
+	{
+		g_object_unref (priv->status_icon);
+		priv->status_icon = NULL;
+	}
+
 	g_hash_table_destroy (dv->priv->downloads_hash);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -471,9 +476,8 @@ update_status_icon (DownloaderView *dv)
 					"%d downloads", downloads), 
 					downloads);
 
-	egg_status_icon_set_tooltip (dv->priv->status_icon,
-				     downloadstring, NULL);
-
+	gtk_status_icon_set_tooltip (dv->priv->status_icon,
+				     downloadstring);
 	g_free (downloadstring);
 }
 
@@ -662,6 +666,7 @@ downloader_view_build_ui (DownloaderView *dv)
 					    "pixbuf", COL_IMAGE,
 					    NULL);
 	renderer = gtk_cell_renderer_text_new ();
+	g_object_set (renderer, "ellipsize", PANGO_ELLIPSIZE_MIDDLE, NULL);
 	gtk_tree_view_column_pack_start (column, renderer, TRUE);
 	gtk_tree_view_column_set_attributes (column, renderer,
 					     "text", COL_FILE,
@@ -849,10 +854,11 @@ download_dialog_delete_event_cb (GtkWidget *window,
 				 GdkEventAny *event,
 				 DownloaderView *dv)
 {
-	/* FIXME multi-head */
-	if (egg_tray_manager_check_running (gdk_screen_get_default ()))
+	DownloaderViewPrivate *priv = dv->priv;
+
+	if (gtk_status_icon_is_embedded (priv->status_icon))
 	{
-		gtk_widget_hide (dv->priv->window);
+		gtk_widget_hide (window);
 	}
 
 	return TRUE;
