@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.cpp,v 1.93 2006/05/10 18:06:59 chpe Exp $
+ *  $Id: ContentHandler.cpp,v 1.94 2006/07/06 13:22:34 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -57,11 +57,11 @@
 #include "ephy-prefs.h"
 #include "ephy-stock-icons.h"
 
+#include "AutoJSContextStack.h"
+#include "AutoWindowModalState.h"
 #include "EphyUtils.h"
 #include "MozDownload.h"
 
-#include "AutoJSContextStack.h"
-
 #include "ContentHandler.h"
 
 /* FIXME: we don't generally have a timestamp for the user action which initiated this
@@ -139,9 +139,11 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 	rv = stack.Init ();
 	if (NS_FAILED (rv)) return rv;
 
-	nsCOMPtr<nsIDOMWindow> parentDOMWindow = do_GetInterface (aWindowContext);
+	nsCOMPtr<nsIDOMWindow> parentDOMWindow (do_GetInterface (aWindowContext));
 	GtkWidget *parentWindow = GTK_WIDGET (EphyUtils::FindGtkParent (parentDOMWindow));
 
+	AutoWindowModalState modalState (parentDOMWindow);
+
 	dialog = ephy_file_chooser_new (_("Save"), parentWindow,
 					GTK_FILE_CHOOSER_ACTION_SAVE,
 					CONF_STATE_SAVE_DIR,
