@@ -17,62 +17,82 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozRegisterComponents.cpp,v 1.48 2006/03/19 20:48:13 jframeau Exp $
+ *  $Id: MozRegisterComponents.cpp,v 1.52 2006/06/23 20:50:40 jframeau Exp $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
+#include <glib/gmessages.h>
+
+#include <nsStringAPI.h>
+
+#include <nsComponentManagerUtils.h>
+#include <nsCOMPtr.h>
+#include <nsCURILoader.h>
+#include <nsDocShellCID.h>
+#include <nsICategoryManager.h>
+#include <nsIComponentManager.h>
+#include <nsIComponentRegistrar.h>
+#include <nsIGenericFactory.h>
+#include <nsILocalFile.h>
+#include <nsIScriptNameSpaceManager.h>
+#include <nsIServiceManager.h>
+#include <nsMemory.h>
+#include <nsNetCID.h>
+#include <nsServiceManagerUtils.h>
+
+#ifdef HAVE_GECKO_1_9
+#include <nsIClassInfoImpl.h>
+#endif
+
+#ifdef HAVE_MOZILLA_PSM
+#include <nsISecureBrowserUI.h>
+#endif
+
 #include "ContentHandler.h"
-#include "GlobalHistory.h"
-#include "PrintingPromptService.h"
-#include "MozDownload.h"
-#include "EphyContentPolicy.h"
-#include "EphySidebar.h"
 #include "EphyAboutModule.h"
+#include "EphyContentPolicy.h"
 #include "EphyPromptService.h"
+#include "EphySidebar.h"
+#include "GeckoPrintService.h"
+#include "GeckoPrintSession.h"
+#include "GlobalHistory.h"
+#include "MozDownload.h"
 
 #ifdef ENABLE_FILEPICKER
 #include "FilePicker.h"
 #endif
 
+#ifdef ENABLE_SPELLCHECKER
+#include "GeckoSpellCheckEngine.h"
+#endif
+
 #ifdef HAVE_MOZILLA_PSM
 #include "GtkNSSClientAuthDialogs.h"
 #include "GtkNSSDialogs.h"
 #include "GtkNSSKeyPairDialogs.h"
 #include "GtkNSSSecurityWarningDialogs.h"
-#include <nsISecureBrowserUI.h>
 #endif
 
-#include <nsMemory.h>
-#include <nsDocShellCID.h>
-#include <nsIGenericFactory.h>
-#include <nsIComponentRegistrar.h>
-#include <nsICategoryManager.h>
-#include <nsCOMPtr.h>
-#include <nsILocalFile.h>
-#include <nsNetCID.h>
-
-#ifdef HAVE_GECKO_1_9
-#include <nsIClassInfoImpl.h>
-#endif
-
-#include <glib/gmessages.h>
-
-NS_GENERIC_FACTORY_CONSTRUCTOR(MozDownload)
-NS_GENERIC_FACTORY_CONSTRUCTOR(GContentHandler)
-NS_GENERIC_FACTORY_CONSTRUCTOR(MozGlobalHistory)
-NS_GENERIC_FACTORY_CONSTRUCTOR(GPrintingPromptService)
-NS_GENERIC_FACTORY_CONSTRUCTOR(EphyContentPolicy)
-NS_GENERIC_FACTORY_CONSTRUCTOR(EphySidebar)
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphyAboutModule)
+NS_GENERIC_FACTORY_CONSTRUCTOR(EphyContentPolicy)
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphyPromptService)
+NS_GENERIC_FACTORY_CONSTRUCTOR(EphySidebar)
+NS_GENERIC_FACTORY_CONSTRUCTOR(GContentHandler)
+NS_GENERIC_FACTORY_CONSTRUCTOR(GeckoPrintService)
+NS_GENERIC_FACTORY_CONSTRUCTOR(GeckoPrintSession)
+NS_GENERIC_FACTORY_CONSTRUCTOR(MozDownload)
+NS_GENERIC_FACTORY_CONSTRUCTOR(MozGlobalHistory)
 
 #ifdef ENABLE_FILEPICKER
 NS_GENERIC_FACTORY_CONSTRUCTOR(GFilePicker)
 #endif
 
+#ifdef ENABLE_SPELLCHECKER
+NS_GENERIC_FACTORY_CONSTRUCTOR(GeckoSpellCheckEngine)
+#endif
+
 #ifdef HAVE_MOZILLA_PSM
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSClientAuthDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSDialogs)
@@ -80,44 +100,50 @@ NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSKeyPairDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSSecurityWarningDialogs)
 #endif
 
+#define XPINSTALL_CONTRACTID NS_CONTENT_HANDLER_CONTRACTID_PREFIX "application/x-xpinstall"
 
 /* class information */ 
 NS_DECL_CLASSINFO(EphySidebar)
 
-static NS_METHOD
-RegisterContentPolicy(nsIComponentManager *aCompMgr, nsIFile *aPath,
-		      const char *registryLocation, const char *componentType,
-		      const nsModuleComponentInfo *info)
+static nsresult
+RegisterCategories (void)
 {
-	nsCOMPtr<nsICategoryManager> cm =
-		do_GetService(NS_CATEGORYMANAGER_CONTRACTID);
-	NS_ENSURE_TRUE (cm, NS_ERROR_FAILURE);
-
 	nsresult rv;
-	char *oldval = nsnull;
-	rv = cm->AddCategoryEntry ("content-policy",
-				   EPHY_CONTENT_POLICY_CONTRACTID,
-				   EPHY_CONTENT_POLICY_CONTRACTID,
-				   PR_TRUE, PR_TRUE, &oldval);
-	if (oldval)
-		nsMemory::Free (oldval);
+	nsCOMPtr<nsICategoryManager> catMan =
+		do_GetService(NS_CATEGORYMANAGER_CONTRACTID, &rv);
+	NS_ENSURE_SUCCESS (rv, rv);
+
+	rv = catMan->AddCategoryEntry ("content-policy",
+				       EPHY_CONTENT_POLICY_CONTRACTID,
+				       EPHY_CONTENT_POLICY_CONTRACTID,
+				       PR_FALSE /* don't persist */,
+				       PR_TRUE /* replace */,
+				       nsnull);
+
+	rv |= catMan->AddCategoryEntry (JAVASCRIPT_GLOBAL_PROPERTY_CATEGORY,
+					"sidebar",
+					NS_SIDEBAR_CONTRACTID,
+					PR_FALSE /* don't persist */,
+					PR_TRUE /* replace */,
+					nsnull);
+
+#ifdef HAVE_GECKO_1_9
+	/* Unregister the XPI install trigger too
+	 * Only do it on gecko 1.9 though, because it breaks in 1.8
+	 * (because of https://bugzilla.mozilla.org/show_bug.cgi?id=329450)
+	 */
+	rv |= catMan->DeleteCategoryEntry (JAVASCRIPT_GLOBAL_CONSTRUCTOR_CATEGORY,
+					   "InstallVersion",
+					   PR_FALSE /* don't persist */);
+	rv |= catMan->DeleteCategoryEntry (JAVASCRIPT_GLOBAL_PROPERTY_CATEGORY,
+					   "InstallTrigger",
+					   PR_FALSE /* don't persist */);
+	NS_ENSURE_SUCCESS (rv, rv);
+#endif
+
 	return rv;
 }
 
-static NS_METHOD
-RegisterSidebar(nsIComponentManager *aCompMgr, nsIFile *aPath,
-                const char *registryLocation, const char *componentType,
-                const nsModuleComponentInfo *info)
-{
-	nsCOMPtr<nsICategoryManager> cm =
-		do_GetService(NS_CATEGORYMANAGER_CONTRACTID);
-	NS_ENSURE_TRUE (cm, NS_ERROR_FAILURE);
-
-	return cm->AddCategoryEntry("JavaScript global property",
-				    "sidebar", NS_SIDEBAR_CONTRACTID,
-				    PR_FALSE, PR_TRUE, nsnull);
-}
-
 static const nsModuleComponentInfo sAppComps[] = {
 	{
 		MOZ_DOWNLOAD_CLASSNAME,
@@ -182,24 +208,29 @@ static const nsModuleComponentInfo sAppComps[] = {
 		MozGlobalHistoryConstructor
 	},
 	{
-		G_PRINTINGPROMPTSERVICE_CLASSNAME,
-		G_PRINTINGPROMPTSERVICE_CID,
-		G_PRINTINGPROMPTSERVICE_CONTRACTID,
-		GPrintingPromptServiceConstructor
+		GECKO_PRINT_SERVICE_CLASSNAME,
+		GECKO_PRINT_SERVICE_IID,
+		"@mozilla.org/embedcomp/printingprompt-service;1",
+		GeckoPrintServiceConstructor
+	},
+	{
+		GECKO_PRINT_SESSION_CLASSNAME,
+		GECKO_PRINT_SESSION_IID,
+		"@mozilla.org/gfx/printsession;1",
+		GeckoPrintSessionConstructor
 	},
 	{
 		EPHY_CONTENT_POLICY_CLASSNAME,
 		EPHY_CONTENT_POLICY_CID,
 		EPHY_CONTENT_POLICY_CONTRACTID,
 		EphyContentPolicyConstructor,
-		RegisterContentPolicy
 	},
 	{
 		EPHY_SIDEBAR_CLASSNAME,
 		EPHY_SIDEBAR_CID,
 		NS_SIDEBAR_CONTRACTID,
 		EphySidebarConstructor,
-		RegisterSidebar,
+		nsnull /* no register func */,
 		nsnull /* no unregister func */,
 		nsnull /* no factory destructor */,
 		NS_CI_INTERFACE_GETTER_NAME(EphySidebar),
@@ -219,14 +250,12 @@ static const nsModuleComponentInfo sAppComps[] = {
 		EPHY_ABOUT_RECOVER_CONTRACTID,
 		EphyAboutModuleConstructor
 	},
-#ifdef HAVE_GECKO_1_8
 	{
 		EPHY_ABOUT_NETERROR_CLASSNAME,
 		EPHY_ABOUT_MODULE_CID,
 		EPHY_ABOUT_NETERROR_CONTRACTID,
 		EphyAboutModuleConstructor
 	},
-#endif
 	{
 		EPHY_PROMPT_SERVICE_CLASSNAME,
 		EPHY_PROMPT_SERVICE_IID,
@@ -241,45 +270,16 @@ static const nsModuleComponentInfo sAppComps[] = {
 		EphyPromptServiceConstructor
 	},
 #endif /* HAVE_NSINONBLOCKINGALERTSERVICE_H */
+#ifdef ENABLE_SPELLCHECKER
+	{
+		GECKO_SPELL_CHECK_ENGINE_CLASSNAME,
+		GECKO_SPELL_CHECK_ENGINE_IID,
+		GECKO_SPELL_CHECK_ENGINE_CONTRACTID,
+		GeckoSpellCheckEngineConstructor
+	}
+#endif /* ENABLE_SPELLCHECK */
 };
 
-#if defined(HAVE_MOZILLA_PSM) && !defined(HAVE_GECKO_1_8)
-/* 5999dfd3-571f-4fcf-964b-386879f5cded */
-#define NEW_CID { 0x5999dfd3, 0x571f, 0x4fcf, { 0x96, 0x4b, 0x38, 0x68, 0x79, 0xf5, 0xcd, 0xed } }
-
-static nsresult
-reregister_secure_browser_ui (nsIComponentManager *cm,
-			      nsIComponentRegistrar *cr)
-{
-	NS_ENSURE_ARG (cm);
-	NS_ENSURE_ARG (cr);
-
-	/* Workaround as a result of:
-	 *  https://bugzilla.mozilla.org/show_bug.cgi?id=94974
-	 * see
-	 *  http://bugzilla.gnome.org/show_bug.cgi?id=164670
-	 */
-
-	nsresult rv;
-	nsCOMPtr<nsIFactory> factory;
-	rv = cm->GetClassObjectByContractID (NS_SECURE_BROWSER_UI_CONTRACTID, NS_GET_IID(nsIFactory), getter_AddRefs (factory));
-	NS_ENSURE_SUCCESS (rv, rv);
-
-	nsCID *cidPtr = nsnull;
-	rv = cr->ContractIDToCID(NS_SECURE_BROWSER_UI_CONTRACTID, &cidPtr);
-	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && cidPtr, rv);
-
-	rv = cr->UnregisterFactory (*cidPtr, factory);
-	NS_ENSURE_SUCCESS (rv, rv);
-
-	const nsCID new_cid = NEW_CID;
-	rv = cr->RegisterFactory (new_cid, "Epiphany Secure Browser Class", "@gnome.org/project/epiphany/hacks/secure-browser-ui;1", factory);
-	nsMemory::Free (cidPtr);
-
-	return rv;
-}
-#endif /* defined(HAVE_MOZILLA_PSM) && !defined(HAVE_GECKO_1_8) */
-
 gboolean
 mozilla_register_components (void)
 {
@@ -330,14 +330,30 @@ mozilla_register_components (void)
 		}
 	}
 
-#if defined(HAVE_MOZILLA_PSM) && !defined(HAVE_GECKO_1_8)
-	/* Workaround for http://bugzilla.gnome.org/show_bug.cgi?id=164670 */
-	rv = reregister_secure_browser_ui (cm, cr);
+	rv = RegisterCategories();
+	ret = NS_SUCCEEDED (rv); 
+
+#ifdef HAVE_GECKO_1_9
+	/* Unregister xpinstall content handler */
+	nsCID *cidPtr = nsnull;
+	rv = cr->ContractIDToCID (XPINSTALL_CONTRACTID, &cidPtr);
+	if (NS_SUCCEEDED (rv) && cidPtr)
+	{
+		nsCOMPtr<nsIFactory> factory;
+		rv = cm->GetClassObject (*cidPtr, NS_GET_IID (nsIFactory),
+					 getter_AddRefs (factory));
+		if (NS_SUCCEEDED (rv))
+		{
+			rv = cr->UnregisterFactory (*cidPtr, factory);
+		}
+
+		nsMemory::Free (cidPtr);
+	}
 	if (NS_FAILED (rv))
 	{
-		g_warning ("Failed to divert the nsISecureBrowserUI implementation!\n");
+		g_warning ("Failed to unregister xpinstall content handler!\n");
 	}
-#endif /* defined(HAVE_MOZILLA_PSM) && !defined(HAVE_GECKO_1_8) */
+#endif
 
 	return ret;
 }
