@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.c,v 1.44 2005/12/11 17:27:13 chpe Exp $
+ *  $Id: ephy-gui.c,v 1.49 2006/05/10 18:07:01 chpe Exp $
  */
 
 #include "config.h"
@@ -250,43 +250,6 @@ ephy_gui_menu_position_on_toolbar (GtkMenu   *menu,
 	*push_in = FALSE;
 }
 
-void
-ephy_gui_menu_position_on_panel (GtkMenu *menu,
-				 gint      *x,
-				 gint      *y,
-				 gboolean  *push_in,
-				 gpointer  user_data)
-{
-	GtkWidget *widget = GTK_WIDGET (user_data);
-	GtkRequisition requisition;
-	GdkScreen *screen;
-
-	screen = gtk_widget_get_screen (widget);
-
-	gdk_window_get_origin (widget->window, x, y);
-	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
-
-	if (GTK_WIDGET_NO_WINDOW (widget))
-	{
-		*x += widget->allocation.x;
-		*y += widget->allocation.y;
-	}
-
-	/* FIXME: Adapt to vertical panels, but egg_tray_icon_get_orientation doesn't seem to work */
-	if (*y > gdk_screen_get_height (screen) / 2)
-	{
-		*y -= requisition.height;
-	}
-	else
-	{
-		*y += widget->allocation.height;
-	}
-
-	*push_in = FALSE;
-
-	ephy_gui_sanitise_popup_position (menu, widget, x, y);
-}
-
 GtkWindowGroup *
 ephy_gui_ensure_window_group (GtkWindow *window)
 {
@@ -391,31 +354,77 @@ ephy_gui_check_location_writable (GtkWidget *parent,
 }
 
 void
-ephy_gui_help (GtkWindow *parent,
-	       const char *file_name,
-               const char *link_id)
+ephy_gui_help_with_doc_id (GtkWindow *parent,
+			   const char *doc_id,
+			   const char *file_name,
+			   const char *link_id)
 {
-	GError *err = NULL;
+	GError *error = NULL;
 
-	gnome_help_display (file_name, link_id, &err);
+	gnome_help_display_with_doc_id (NULL, doc_id, file_name, link_id, &error);
 
-	if (err != NULL)
+	if (error != NULL)
 	{
 		GtkWidget *dialog;
+
 		dialog = gtk_message_dialog_new (parent,
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_ERROR,
 						 GTK_BUTTONS_OK,
-						 _("Could not display help: %s"), err->message);
-		g_signal_connect (G_OBJECT (dialog), "response",
-				  G_CALLBACK (gtk_widget_destroy),
-				  NULL);
-		gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+						 _("Could not display help: %s"),
+						 error->message);
+		g_error_free (error);
+
+		g_signal_connect (dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy), NULL);
 		gtk_widget_show (dialog);
-		g_error_free (err);
 	}
 }
 
+void
+ephy_gui_help (GtkWindow *parent,
+	       const char *file_name,
+               const char *link_id)
+{
+	ephy_gui_help_with_doc_id (parent, NULL, file_name, link_id);
+}
+
+void
+ephy_gui_get_current_event (GdkEventType *otype,
+			    guint *ostate,
+			    guint *obutton)
+{
+	GdkEvent *event;
+	GdkEventType type = GDK_NOTHING;
+	guint state = 0, button = (guint) -1;
+
+	event = gtk_get_current_event ();
+	if (event != NULL)
+	{
+		type = event->type;
+
+		if (type == GDK_KEY_PRESS ||
+		    type == GDK_KEY_RELEASE)
+		{
+			state = event->key.state;
+		}
+		else if (type == GDK_BUTTON_PRESS ||
+			 type == GDK_BUTTON_RELEASE ||
+			 type == GDK_2BUTTON_PRESS ||
+			 type == GDK_3BUTTON_PRESS)
+		{
+			button = event->button.button;
+			state = event->button.state;
+		}
+
+		gdk_event_free (event);
+	}
+	
+	if (otype) *otype = type;
+	if (ostate) *ostate = state & gtk_accelerator_get_default_mod_mask ();
+	if (obutton) *obutton = button;
+}
+
 gboolean
 ephy_gui_is_middle_click (void)
 {
@@ -462,31 +471,26 @@ ephy_gui_window_update_user_time (GtkWidget *window,
 
 }
 
-/* gtk+ bug 166379 */
-/* adapted from gtk+/gtk/gtkwindow.c */
-void
-ephy_gui_window_present (GtkWindow *window,
-			 guint32 user_time)
+/* Pending gtk+ bug http://bugzilla.gnome.org/show_bug.cgi?id=328069 */
+GtkWidget *
+ephy_gui_message_dialog_get_content_box (GtkWidget *dialog)
 {
-	GtkWidget *widget;
-	
-	g_return_if_fail (GTK_IS_WINDOW (window));
-	
-	widget = GTK_WIDGET (window);
-	
-	if (GTK_WIDGET_VISIBLE (window))
-	{
-		g_assert (widget->window != NULL);
+	GtkWidget *container;
+	GList *children;
 
-		gdk_window_show (widget->window);
+	/* Get the hbox which is the first child of the main vbox */
+	children = gtk_container_get_children (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox));
+	g_return_val_if_fail (children != NULL, NULL);
 
-		/* note that gdk_window_focus() will also move the window to
-		* the current desktop, for WM spec compliant window managers.
-		*/
-		gdk_window_focus (widget->window, user_time);
-	}
-	else
-	{
-		gtk_widget_show (widget);
-	}
+	container = GTK_WIDGET (children->data);
+	g_list_free (children);
+
+	/* Get the vbox which is the second child of the hbox */
+	children = gtk_container_get_children (GTK_CONTAINER (container));
+	g_return_val_if_fail (children != NULL && children->next != NULL, NULL);
+
+	container = GTK_WIDGET (children->next->data);
+	g_list_free (children);
+
+	return container;
 }
