@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-langs.c,v 1.16 2005/01/28 22:24:03 chpe Exp $
+ *  $Id: ephy-langs.c,v 1.21 2006/05/10 18:07:01 chpe Exp $
  */
 
 #include "config.h"
@@ -28,10 +28,11 @@
 
 #include <string.h>
 
-#ifdef HAVE_ISO_CODES
 #include <libxml/xmlreader.h>
-#endif
 
+/* If you add more language codes here, remember to also
+ * add them to data/generate-font-schemas.py .
+ */
 static const EphyFontsLanguageInfo font_languages [] =
 {
 	/* Translators: The text before the "|" is context to help you decide on
@@ -81,12 +82,38 @@ static const EphyFontsLanguageInfo font_languages [] =
 	{ N_("select fonts for|Turkish"),				"tr" },
 	/* Translators: The text before the "|" is context to help you decide on
 	 * the correct translation. You MUST OMIT it in the translated string. */
-	{ N_("select fonts for|Unicode"),				"x-unicode" },
+	{ N_("select fonts for|Armenian"),				"x-armn" },
 	/* Translators: The text before the "|" is context to help you decide on
 	 * the correct translation. You MUST OMIT it in the translated string. */
-	{ N_("select fonts for|Western"),				"x-western" }
+	{ N_("select fonts for|Bengali"),				"x-beng" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Unified Canadian Syllabics"),		"x-cans" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Ethiopic"),				"x-ethi" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Georgian"),				"x-geor" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Gujarati"),				"x-gujr" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Gurmukhi"),				"x-guru" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Khmer"),					"x-khmr" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Malayalam"),				"x-mlym" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Western"),				"x-western" },
+	/* Translators: The text before the "|" is context to help you decide on
+	 * the correct translation. You MUST OMIT it in the translated string. */
+	{ N_("select fonts for|Other Scripts"),				"x-unicode" }
 };
-static const guint n_font_languages = G_N_ELEMENTS (font_languages);
 
 const EphyFontsLanguageInfo *
 ephy_font_languages (void)
@@ -97,7 +124,7 @@ ephy_font_languages (void)
 guint			 
 ephy_font_n_languages (void)
 {
-	return n_font_languages;
+	return G_N_ELEMENTS (font_languages);
 }
 
 /* sanitise the languages list according to the rules for HTTP accept-language
@@ -221,8 +248,6 @@ ephy_langs_get_languages (void)
 	return (char **) g_array_free (array, FALSE);
 }
 
-#ifdef HAVE_ISO_CODES
-
 #define ISOCODESLOCALEDIR	ISO_CODES_PREFIX "/share/locale"
 
 static void
@@ -324,8 +349,8 @@ load_iso_entries (int iso,
 	reader = xmlNewTextReaderFilename (filename);
 	if (reader == NULL) goto out;
 
-	xmlStrPrintf (iso_entries, sizeof (iso_entries), "iso_%d_entries", iso);
-	xmlStrPrintf (iso_entry, sizeof (iso_entry), "iso_%d_entry", iso);
+	xmlStrPrintf (iso_entries, sizeof (iso_entries), (const xmlChar *)"iso_%d_entries", iso);
+	xmlStrPrintf (iso_entry, sizeof (iso_entry), (const xmlChar *)"iso_%d_entry", iso);
 
 	ret = xmlTextReaderRead (reader);
 
@@ -413,5 +438,3 @@ ephy_langs_iso_3166_table (void)
 
 	return table;
 }
-
-#endif /* HAVE_ISO_CODES */
