@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tree-model-node.c,v 1.20 2004/11/02 20:57:20 chpe Exp $
+ *  $Id: ephy-tree-model-node.c,v 1.23 2005/11/08 12:46:39 chpe Exp $
  */
 
 #include "config.h"
@@ -36,7 +36,7 @@ static void ephy_tree_model_node_tree_model_init (GtkTreeModelIface *iface);
 
 #define EPHY_TREE_MODEL_NODE_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TREE_MODEL_NODE, EphyTreeModelNodePrivate))
 
-struct EphyTreeModelNodePrivate
+struct _EphyTreeModelNodePrivate
 {
 	EphyNode *root;
 
@@ -162,7 +162,7 @@ ephy_tree_model_node_update_node (EphyTreeModelNode *model,
 		path = get_path_real (model, node);
 	}
 
-	LOG ("Updating row")
+	LOG ("Updating row");
 
 	gtk_tree_model_row_changed (GTK_TREE_MODEL (model), path, &iter);
 	gtk_tree_path_free (path);
@@ -276,7 +276,7 @@ ephy_tree_model_node_class_init (EphyTreeModelNodeClass *klass)
 					 g_param_spec_pointer ("root",
 							      "Root node",
 							      "Root node",
-							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT_ONLY));
 
 	g_type_class_add_private (object_class, sizeof (EphyTreeModelNodePrivate));
 }
