@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks-import.c,v 1.42 2005/02/26 22:30:20 chpe Exp $
+ *  $Id: ephy-bookmarks-import.c,v 1.46 2006/03/02 21:30:03 chpe Exp $
  */
 
 #include "config.h"
@@ -69,44 +69,60 @@ ephy_bookmarks_import (EphyBookmarks *bookmarks,
 		       const char *filename)
 {
 	const char *type;
+	char *basename;
 	gboolean success = FALSE;
 
 	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING)) return FALSE;
 
+	g_return_val_if_fail (filename != NULL, FALSE);
+
 	type = gnome_vfs_get_file_mime_type (filename, NULL, FALSE);
 
 	LOG ("Importing bookmarks of type %s", type ? type : "(null)");
 
-	if (type == NULL)
-	{
-		g_warning ("Couldn't determine the type of the bookmarks file %s!\n", filename);
-	}
-	else if (strcmp (type, "application/x-mozilla-bookmarks") == 0)
-	{
-		success = ephy_bookmarks_import_mozilla (bookmarks, filename);
-	}
-	else if (strcmp (type, "application/x-xbel") == 0)
-	{
-		success = ephy_bookmarks_import_xbel (bookmarks, filename);
-	}
-	else if (strcmp (type, "application/rdf+xml") == 0 ||
-		 strcmp (type, "text/rdf") == 0)
+	if (type != NULL && (strcmp (type, "application/rdf+xml") == 0 ||
+			     strcmp (type, "text/rdf") == 0))
 	{
 		success = ephy_bookmarks_import_rdf (bookmarks, filename);
 	}
-	else if (strstr (filename, MOZILLA_BOOKMARKS_DIR) != NULL ||
+	else if ((type != NULL && strcmp (type, "application/x-xbel") == 0) ||
+		 strstr (filename, GALEON_BOOKMARKS_DIR) != NULL ||
+		 strstr (filename, KDE_BOOKMARKS_DIR) != NULL)
+	{
+		success = ephy_bookmarks_import_xbel (bookmarks, filename);
+	}
+	else if ((type != NULL && strcmp (type, "application/x-mozilla-bookmarks") == 0) ||
+	         strstr (filename, MOZILLA_BOOKMARKS_DIR) != NULL ||
                  strstr (filename, FIREFOX_BOOKMARKS_DIR_0) != NULL ||
                  strstr (filename, FIREFOX_BOOKMARKS_DIR_1) != NULL ||
 		 strstr (filename, FIREFOX_BOOKMARKS_DIR_2) != NULL)
 	{
 		success = ephy_bookmarks_import_mozilla (bookmarks, filename);
 	}
-	else if (strstr (filename, GALEON_BOOKMARKS_DIR) != NULL ||
-		 strstr (filename, KDE_BOOKMARKS_DIR) != NULL)
+	else if (type == NULL)
 	{
-		success = ephy_bookmarks_import_xbel (bookmarks, filename);
+		basename = g_path_get_basename (filename);
+
+		if (g_str_has_suffix (basename, ".rdf"))
+		{
+			success = ephy_bookmarks_import_rdf (bookmarks, filename);
+		}
+		else if (g_str_has_suffix (basename, ".xbel"))
+		{
+			success = ephy_bookmarks_import_xbel (bookmarks, filename);
+		}
+		else if (g_str_has_suffix (basename, ".html"))
+		{
+			success = ephy_bookmarks_import_mozilla (bookmarks, filename);
+		}
+		else
+		{
+			/* else FIXME: put up some UI to warn user about unrecognised format? */
+			g_warning ("Couldn't determine the type of the bookmarks file %s!\n", filename);
+		}
+
+		g_free (basename);
 	}
-	/* else FIXME: put up some UI to warn user about unrecognised format? */
 
 	return success;
 }
@@ -261,7 +277,7 @@ xbel_parse_bookmark (EphyBookmarks *eb, xmlTextReaderPtr reader, EphyNode **ret_
 }
 
 static int
-xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_folder)
+xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, GList *folders)
 {
 	EphyXBELImporterState state = STATE_FOLDER;
 	char *folder = NULL;
@@ -285,22 +301,9 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 		{
 			if (state == STATE_TITLE && folder == NULL)
 			{
-				char *title;
-
-				title = (char *) xmlTextReaderValue (reader);
-
-				if (!parent_folder)
-				{
-					folder = g_strdup (title);
-				}
-				else
-				{
-					folder = g_strconcat (parent_folder,
-							      BOOKMARKS_HIERARCHY_SEP,
-							      title, NULL);
-				}
-
-				g_free (title);
+				folder = (char *) xmlTextReaderValue (reader);
+				
+				folders = g_list_prepend (folders, folder);
 			}
 			else
 			{
@@ -310,19 +313,27 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 		else if (xmlStrEqual (tag, (xmlChar *) "bookmark") && type == 1 && state == STATE_FOLDER)
 		{
 			EphyNode *node = NULL, *keyword;
+			GList *l;
 
 			ret = xbel_parse_bookmark (eb, reader, &node);
 
-			keyword = ephy_bookmarks_find_keyword (eb, folder ? folder : "", FALSE);
+			for (l = folders; l != NULL; l=l->next)
+			{
+				char *title;
+				
+				title = l->data ? (char *) l->data : "";
+				
+				keyword = ephy_bookmarks_find_keyword (eb, title, FALSE);
 			
-			if (keyword == NULL && folder != NULL && folder[0] != '\0')
-			{
-				keyword = ephy_bookmarks_add_keyword (eb, folder);
-			}
+				if (keyword == NULL && title[0] != '\0')
+				{
+					keyword = ephy_bookmarks_add_keyword (eb, title);
+				}
 
-			if (node != NULL && keyword != NULL)
-			{
-				ephy_bookmarks_set_keyword (eb, keyword, node);
+				if (node != NULL && keyword != NULL)
+				{
+					ephy_bookmarks_set_keyword (eb, keyword, node);
+				}
 			}
 
 			if (ret != 1) break;
@@ -332,7 +343,7 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 		{
 			if (type == XML_READER_TYPE_ELEMENT)
 			{
-				ret = xbel_parse_folder (eb, reader, folder ? folder : "");
+				ret = xbel_parse_folder (eb, reader, folders);
 				
 				if (ret != 1) break;
 			}
@@ -384,8 +395,12 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 		/* next one, please */
 		ret = xmlTextReaderRead (reader);
 	}
-
-	g_free (folder);
+	
+	if (folder)
+	{
+		folders = g_list_remove (folders, folder);
+		g_free (folder);
+	}
 
 	return ret;
 }
@@ -488,10 +503,12 @@ gul_general_read_line_from_file (FILE *f)
 	gchar *t;
 	gchar *buf = g_new0 (gchar, 256);
 	while ( ! ( strchr (buf, '\n') || feof (f) ) ) {
-		fgets(buf, 256, f);
-		t = line;
-		line = g_strconcat (line, buf, NULL);
-		g_free (t);
+		if (fgets(buf, 256, f))
+		{
+			t = line;
+			line = g_strconcat (line, buf, NULL);
+			g_free (t);
+		}
 	}
 	g_free (buf);
 	return line;
@@ -658,32 +675,13 @@ ns_parse_bookmark_item (GString *string)
 	return temp;
 }
 
-static char *
-folders_list_to_topic_name (GList *folders)
-{
-	GString *topic;
-	GList *l;
-
-	g_return_val_if_fail (folders != NULL, NULL);
-
-	topic = g_string_new (folders->data);
-
-	for (l = folders->next; l != NULL; l = l->next)
-	{
-		g_string_append (topic, BOOKMARKS_HIERARCHY_SEP);
-		g_string_append (topic, l->data);
-	}
-
-	return g_string_free (topic, FALSE);
-}
-
 gboolean
 ephy_bookmarks_import_mozilla (EphyBookmarks *bookmarks,
 			       const char *filename)
 {
 	FILE *bf;  /* bookmark file */
 	GString *name, *url;
-	char *parsedname, *topic;
+	char *parsedname;
 	GList *folders = NULL;
 
 	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING)) return FALSE;
@@ -731,18 +729,18 @@ ephy_bookmarks_import_mozilla (EphyBookmarks *bookmarks,
 			if (folders != NULL)
 			{
 				EphyNode *keyword;
+				GList *l;
 
-				topic = folders_list_to_topic_name (folders);
-				g_return_val_if_fail (topic != NULL, FALSE);
-
-				keyword = ephy_bookmarks_find_keyword (bookmarks, topic, FALSE);
-				if (keyword == NULL)
+				for (l = folders; l != NULL; l = l->next)
 				{
-					keyword = ephy_bookmarks_add_keyword (bookmarks, topic);
-				}
-				g_free (topic);
+					keyword = ephy_bookmarks_find_keyword (bookmarks, l->data, FALSE);
+					if (keyword == NULL)
+					{
+						keyword = ephy_bookmarks_add_keyword (bookmarks, l->data);
+					}
 
-				ephy_bookmarks_set_keyword (bookmarks, keyword, node);
+					ephy_bookmarks_set_keyword (bookmarks, keyword, node);
+				}
 			}
 
 			g_free (parsedname);
