@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-action.c,v 1.40 2005/08/01 19:28:53 chpe Exp $
+ *  $Id: ephy-location-action.c,v 1.45 2006/07/10 19:23:45 chpe Exp $
  */
 
 #include "config.h"
@@ -50,6 +50,7 @@ struct _EphyLocationActionPrivate
 	char *lock_tooltip;
 	guint editable : 1;
 	guint show_lock : 1;
+	guint secure : 1;
 };
 
 static void ephy_location_action_init       (EphyLocationAction *action);
@@ -69,6 +70,7 @@ enum
 	PROP_ICON,
 	PROP_LOCK_STOCK,
 	PROP_LOCK_TOOLTIP,
+	PROP_SECURE,
 	PROP_SHOW_LOCK,
 	PROP_WINDOW
 };
@@ -133,12 +135,13 @@ action_activated_cb (GtkEntryCompletion *completion,
 
 		url = ephy_bookmarks_resolve_address
 			(action->priv->bookmarks, smart_url, content);
-		g_return_if_fail (url != NULL);
-
-		ephy_link_open (EPHY_LINK (action), url, NULL, 0);
-	
-		g_free (url);
 		g_free (content);
+		if (url == NULL) return;
+
+ 		ephy_link_open (EPHY_LINK (action), url, NULL,
+			        ephy_link_flags_from_current_event ());
+
+		g_free (url);
 	}
 }
 
@@ -147,8 +150,6 @@ entry_activate_cb (GtkEntry *entry,
 		   EphyLocationAction *action)
 {
 	EphyBookmarks *bookmarks;
-	GdkEvent *event;
-	gboolean control = FALSE;
 	const char *content;
 	char *address;
 
@@ -160,21 +161,8 @@ entry_activate_cb (GtkEntry *entry,
 	address = ephy_bookmarks_resolve_address (bookmarks, content, NULL);
 	g_return_if_fail (address != NULL);
 
-	event = gtk_get_current_event ();
-	if (event)
-	{
-		if (event->type == GDK_KEY_PRESS ||
-		    event->type == GDK_KEY_RELEASE)
-		{
-			control = (event->key.state & gtk_accelerator_get_default_mod_mask ()) == GDK_CONTROL_MASK;
-		}
-			
-		gdk_event_free (event);
-	}
-
-	/* FIXME use ephy_bookmarks_resolve_address here too? */
 	ephy_link_open (EPHY_LINK (action), address, NULL, 
-			control ? EPHY_LINK_NEW_TAB : 0);
+		        ephy_link_flags_from_current_event ());
 
 	g_free (address);
 }
@@ -266,6 +254,18 @@ sync_lock_tooltip (GtkAction *gaction,
 	ephy_location_entry_set_lock_tooltip (entry, priv->lock_tooltip);
 }
 
+static void
+sync_secure (GtkAction *gaction,
+	     GParamSpec *pspec,
+	     GtkWidget *proxy)
+{
+	EphyLocationAction *action = EPHY_LOCATION_ACTION (gaction);
+	EphyLocationActionPrivate *priv = action->priv;
+	EphyLocationEntry *entry = EPHY_LOCATION_ENTRY (proxy);
+
+	ephy_location_entry_set_secure (entry, priv->secure);
+}
+
 static void
 sync_show_lock (GtkAction *gaction,
 	        GParamSpec *pspec,
@@ -387,6 +387,9 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 		sync_lock_tooltip (action, NULL, proxy);
 		g_signal_connect_object (action, "notify::lock-tooltip",
 					 G_CALLBACK (sync_lock_tooltip), proxy, 0);
+		sync_secure (action, NULL, proxy);
+		g_signal_connect_object (action, "notify::secure",
+					 G_CALLBACK (sync_secure), proxy, 0);
 		sync_show_lock (action, NULL, proxy);
 		g_signal_connect_object (action, "notify::show-lock",
 					 G_CALLBACK (sync_show_lock), proxy, 0);
@@ -461,6 +464,9 @@ ephy_location_action_set_property (GObject *object,
 			g_free (priv->lock_tooltip);
 			priv->lock_tooltip = g_value_dup_string (value);
 			break;
+		case PROP_SECURE:
+			priv->secure = g_value_get_boolean (value);
+			break;
 		case PROP_SHOW_LOCK:
 			priv->show_lock = g_value_get_boolean (value);
 			break;
@@ -496,6 +502,9 @@ ephy_location_action_get_property (GObject *object,
 		case PROP_LOCK_TOOLTIP:
 			g_value_set_string (value, priv->lock_tooltip);
 			break;
+		case PROP_SECURE:
+			g_value_set_boolean (value, priv->secure);
+			break;
 		case PROP_SHOW_LOCK:
 			g_value_set_boolean (value, priv->show_lock);
 			break;
@@ -537,14 +546,14 @@ ephy_location_action_class_init (EphyLocationActionClass *class)
 							      "Address",
 							      "The address",
 							      "",
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	g_object_class_install_property (object_class,
 					 PROP_EDITABLE,
 					 g_param_spec_boolean ("editable",
 							       "Editable",
 							       "Editable",
 							       TRUE,
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_ICON,
@@ -552,7 +561,7 @@ ephy_location_action_class_init (EphyLocationActionClass *class)
 							      "Icon",
 							      "The icon",
 							      GDK_TYPE_PIXBUF,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_LOCK_STOCK,
@@ -560,7 +569,7 @@ ephy_location_action_class_init (EphyLocationActionClass *class)
 							       "Lock Stock ID",
 							       "Lock Stock ID",
 							       NULL,
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_LOCK_TOOLTIP,
@@ -568,7 +577,15 @@ ephy_location_action_class_init (EphyLocationActionClass *class)
 							       "Lock Tooltip",
 							       "The icon",
 							       NULL,
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+
+	g_object_class_install_property (object_class,
+					 PROP_SECURE,
+					 g_param_spec_boolean ("secure",
+							       "Secure",
+							       "Secure",
+							       FALSE,
+							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_SHOW_LOCK,
@@ -576,7 +593,7 @@ ephy_location_action_class_init (EphyLocationActionClass *class)
 							       "Show Lock",
 							       "Show Lock",
 							       FALSE,
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	g_object_class_install_property (object_class,
 					 PROP_WINDOW,
@@ -584,7 +601,7 @@ ephy_location_action_class_init (EphyLocationActionClass *class)
 							      "Window",
 							      "The navigation window",
 							      G_TYPE_OBJECT,
-							      G_PARAM_WRITABLE |
+							      G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 							      G_PARAM_CONSTRUCT_ONLY));
 
 	g_type_class_add_private (object_class, sizeof (EphyLocationActionPrivate));
