@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-statusbar.c,v 1.17 2005/01/30 20:09:58 chpe Exp $
+ *  $Id: ephy-statusbar.c,v 1.20 2006/03/28 20:06:55 chpe Exp $
  */
 
 #include "config.h"
@@ -26,6 +26,8 @@
 #include "ephy-stock-icons.h"
 
 #include <string.h>
+#include <glib/gi18n.h>
+#include <gtk/gtklabel.h>	
 #include <gtk/gtkprogressbar.h>
 #include <gtk/gtkeventbox.h>
 #include <gtk/gtkimage.h>
@@ -44,6 +46,7 @@ struct _EphyStatusbarPrivate
 {
 	GtkWidget *icon_container;
 
+	GtkWidget *caret_indicator;
 	GtkWidget *security_icon;
 	GtkWidget *progressbar;
 	GtkWidget *security_evbox;
@@ -91,6 +94,38 @@ ephy_statusbar_class_init (EphyStatusbarClass *klass)
 	g_type_class_add_private (object_class, sizeof (EphyStatusbarPrivate));
 }
 
+static void
+create_caret_indicator (EphyStatusbar *statusbar)
+{
+	EphyStatusbarPrivate *priv = statusbar->priv;
+	GtkWidget *label, *ebox;
+
+	priv->caret_indicator = gtk_frame_new (NULL);
+	gtk_frame_set_shadow_type (GTK_FRAME (priv->caret_indicator),
+				   GTK_SHADOW_IN);
+	ebox = gtk_event_box_new ();
+	gtk_event_box_set_visible_window (GTK_EVENT_BOX (ebox), FALSE);
+	gtk_container_add (GTK_CONTAINER (priv->caret_indicator), ebox);
+	gtk_widget_show (ebox);
+
+	/* Translators: this is displayed in the statusbar; choose a short word
+	 * or even an abbreviation.
+	 */
+	label = gtk_label_new (_("Caret"));
+	gtk_container_add (GTK_CONTAINER (ebox), label);
+	gtk_widget_show (label);
+
+	gtk_tooltips_set_tip (statusbar->tooltips, ebox,
+			      /* Translators: this is the tooltip on the "Caret" icon
+			       * in the statusbar.
+			       */
+			      _("In keyboard selection mode, press F7 to exit"),
+			      NULL);
+
+	gtk_box_pack_start (GTK_BOX (priv->icon_container), priv->caret_indicator,
+			    FALSE, FALSE, 0);
+}
+
 static void
 create_statusbar_security_icon (EphyStatusbar *s)
 {
@@ -186,8 +221,7 @@ ephy_statusbar_init (EphyStatusbar *t)
 	t->priv = EPHY_STATUSBAR_GET_PRIVATE (t);
 
 	t->tooltips = gtk_tooltips_new ();
-	g_object_ref (G_OBJECT (t->tooltips));
-	gtk_object_sink (GTK_OBJECT (t->tooltips));
+	g_object_ref_sink (t->tooltips);
 
 	t->priv->icon_container = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (t), t->priv->icon_container, FALSE, FALSE, 0);
@@ -199,6 +233,7 @@ ephy_statusbar_init (EphyStatusbar *t)
 	create_statusbar_progress (t);
 	create_statusbar_security_icon (t);
 	create_statusbar_popups_manager_icon (t);
+	create_caret_indicator (t);
 
 	sync_shadow_type (t, NULL, NULL);
 	g_signal_connect (t, "style-set", G_CALLBACK (sync_shadow_type), NULL);
@@ -227,6 +262,24 @@ ephy_statusbar_new (void)
 	return GTK_WIDGET (g_object_new (EPHY_TYPE_STATUSBAR, NULL));
 }
 
+/**
+ * ephy_statusbar_set_caret_mode:
+ * @statusbar: an #EphyStatusbar
+ * @enabled:
+ * 
+ * Sets the statusbar's caret browsing mode indicator.
+ **/
+void
+ephy_statusbar_set_caret_mode (EphyStatusbar *statusbar,
+			       gboolean enabled)
+{
+	EphyStatusbarPrivate *priv = statusbar->priv;
+
+	enabled = enabled != FALSE;
+
+	g_object_set (priv->caret_indicator, "visible", enabled, NULL);
+}
+
 /**
  * ephy_statusbar_set_security_state:
  * @statusbar: an #EphyStatusbar
@@ -345,3 +398,32 @@ ephy_statusbar_remove_widget (EphyStatusbar *statusbar,
 	gtk_container_remove (GTK_CONTAINER (statusbar->priv->icon_container),
 			      widget);
 }
+
+
+/**
+ * ephy_statusbar_get_tooltips:
+ * @statusbar: an #EphyStatusbar
+ *
+ * Return value: the statusbar's #GtkTooltips object
+ */
+GtkTooltips *
+ephy_statusbar_get_tooltips (EphyStatusbar *statusbar)
+{
+	g_return_val_if_fail (EPHY_IS_STATUSBAR (statusbar), NULL);
+
+	return statusbar->tooltips;
+}
+
+/**
+ * ephy_statusbar_get_security_frame:
+ * @statusbar: an #EphyStatusbar
+ *
+ * Return value: the statusbar's lock icon frame
+ */
+GtkWidget *
+ephy_statusbar_get_security_frame (EphyStatusbar *statusbar)
+{
+	g_return_val_if_fail (EPHY_IS_STATUSBAR (statusbar), NULL);
+
+	return statusbar->security_frame;
+}
